# Credits

## Development Lead

* Elle Smith <eleanor.smith@stfc.ac.uk>

## Co-Developers

* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_

## Contributors

None yet. Why not be the first?
